@@ -12,7 +12,7 @@
 #'
 #' @examples
 #' set_time_locale("eng")
-#' Sys.setlocale("LC_TIME", "")  # reset to default
+#' set_time_locale("")  # reset to default
 set_time_locale <- function(language_code) {
   assert_that(is.string(language_code))
   assert_that(
@@ -49,5 +49,13 @@ set_time_locale <- function(language_code) {
     new <- suppressWarnings(Sys.setlocale("LC_TIME", lang_format))
   }
 
+  # Locale couldn't be set
+  if (language_code != "" && new == "") {
+    stop(paste0(
+      "Couldn't set locale to '",
+      language_code,
+      "'. Are you sure it's installed on the system?"
+    ))
+  }
   return(new)
 }
